@@ -17,6 +17,10 @@ urlpatterns = patterns(r'',
     url(r'^settings/$', SettingsListView.as_view(),
         name='djangomaster_settings'),
 
+
+    url(r'^tudo/(\d+)/(\d+)$', HomeView.as_view(), name='djangomaster_tudo'),
+    url(r'^nada/(?P<nada>\w+)$', HomeView.as_view(), name='djangomaster_nada'),
+
 )
 
 if STATIC_ACTIVATED:
